@@ -5,8 +5,8 @@
 ;; Author: Jonas Meurer
 ;; Keywords: text, wp, org, typst
 ;; URL: https://github.com/jmpunkt/ox-typst
-;; Package-Version: 20251112.1800
-;; Package-Revision: d75218627ca8
+;; Package-Version: 20251130.1244
+;; Package-Revision: ac8893c79fa8
 ;; Package-Requires: ((emacs "30.1") (org "9.7"))
 
 ;; This file is not part of GNU Emacs.
@@ -342,7 +342,7 @@ will result in `ox-typst' to apply the colors to the code block."
 
 (defun org-typst-item (item contents info)
   (when-let* ((parent (org-export-get-parent item))
-              (trimmed (org-trim contents)))
+              (trimmed (org-trim (if (stringp contents) contents ""))))
     (pcase (org-element-property :type parent)
       ;; NOTE: unordered list items are all represented as single lists
       ('unordered trimmed)
@@ -1060,6 +1060,7 @@ dependencies.  Other converts rely on external dependencies."
      (replace-regexp-in-string "^[ \t]*\\\\\\[" "$" latex-fragment)))))
 
 ;; Commands
+;;;###autoload
 (defun org-typst-export-as-typst
     (&optional async subtreep visible-only body-only ext-plist)
   "Export current buffer as a Typst buffer.
@@ -1099,6 +1100,7 @@ will use the major mode specified by `org-typst-export-buffer-major-mode'."
                                org-typst-export-buffer-major-mode)
                             org-typst-export-buffer-major-mode))))
 
+;;;###autoload
 (defun org-typst-export-to-typst
     (&optional async subtreep visible-only body-only ext-plist)
   "Export Org-buffer to Typst.
@@ -1127,6 +1129,7 @@ Org default settings, but still inferior to file-local settings."
     (org-export-to-file 'typst outfile
                         async subtreep visible-only body-only ext-plist)))
 
+;;;###autoload
 (defun org-typst-export-to-pdf
     (&optional async subtreep visible-only body-only ext-plist)
   "Export Org-buffer as PDF using Typst.
